library(testthat)
library(censobr)
library(dplyr)

testthat::test_check("censobr")
